diff sat/plugins/plugin_xep_0352.py @ 4037:524856bd7b19

massive refactoring to switch from camelCase to snake_case: historically, Libervia (SàT before) was using camelCase as allowed by PEP8 when using a pre-PEP8 code, to use the same coding style as in Twisted. However, snake_case is more readable and it's better to follow PEP8 best practices, so it has been decided to move on full snake_case. Because Libervia has a huge codebase, this ended with a ugly mix of camelCase and snake_case. To fix that, this patch does a big refactoring by renaming every function and method (including bridge) that are not coming from Twisted or Wokkel, to use fully snake_case. This is a massive change, and may result in some bugs.
author Goffi <goffi@goffi.org>
date Sat, 08 Apr 2023 13:54:42 +0200
parents be6d91572633
children
line wrap: on
line diff
--- a/sat/plugins/plugin_xep_0352.py	Fri Apr 07 15:18:39 2023 +0200
+++ b/sat/plugins/plugin_xep_0352.py	Sat Apr 08 13:54:42 2023 +0200
@@ -44,21 +44,21 @@
     def __init__(self, host):
         log.info(_("Client State Indication plugin initialization"))
         self.host = host
-        host.registerNamespace("csi", NS_CSI)
+        host.register_namespace("csi", NS_CSI)
 
-    def isActive(self, client):
+    def is_active(self, client):
         try:
             if not client._xep_0352_enabled:
                 return True
             return client._xep_0352_active
         except AttributeError:
-            # _xep_0352_active can not be set if isActive is called before
-            # profileConnected has been called
-            log.debug("isActive called when XEP-0352 plugin has not yet set the "
+            # _xep_0352_active can not be set if is_active is called before
+            # profile_connected has been called
+            log.debug("is_active called when XEP-0352 plugin has not yet set the "
                       "attributes")
             return True
 
-    def profileConnected(self, client):
+    def profile_connected(self, client):
         if (NS_CSI, 'csi') in client.xmlstream.features:
             log.info(_("Client State Indication is available on this server"))
             client._xep_0352_enabled = True
@@ -68,15 +68,15 @@
                           " bandwidth optimisations can't be used."))
             client._xep_0352_enabled = False
 
-    def setInactive(self, client):
-        if self.isActive(client):
+    def set_inactive(self, client):
+        if self.is_active(client):
             inactive_elt = domish.Element((NS_CSI, 'inactive'))
             client.send(inactive_elt)
             client._xep_0352_active = False
             log.info("inactive state set")
 
-    def setActive(self, client):
-        if not self.isActive(client):
+    def set_active(self, client):
+        if not self.is_active(client):
             active_elt = domish.Element((NS_CSI, 'active'))
             client.send(active_elt)
             client._xep_0352_active = True